summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/transactioneditor.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/transactioneditor.h')
-rw-r--r--kmymoney2/dialogs/transactioneditor.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmymoney2/dialogs/transactioneditor.h b/kmymoney2/dialogs/transactioneditor.h
index 72ecff8..5d3bc96 100644
--- a/kmymoney2/dialogs/transactioneditor.h
+++ b/kmymoney2/dialogs/transactioneditor.h
@@ -212,13 +212,13 @@ signals:
/**
* This signal is sent out, when a new category needs to be created
* Depending on the setting of either a payment or deposit, the tqparent
* account will be preset to Expense or Income.
*
* @param account reference to account info. Will be filled by called slot
* @param tqparent reference to tqparent account
*/
- void createCategory(MyMoneyAccount& account, const MyMoneyAccount& tqparent);
+ void createCategory(MyMoneyAccount& account, const MyMoneyAccount& parent);
/**
* This signal is sent out, when a new security (e.g. stock )needs to be created
@@ -226,9 +226,9 @@ signals:
* will be created.
*
* @param account reference to account info. Will be filled by called slot
* @param tqparent reference to tqparent account
*/
- void createSecurity(MyMoneyAccount& account, const MyMoneyAccount& tqparent);
+ void createSecurity(MyMoneyAccount& account, const MyMoneyAccount& parent);
/**
* Signal is emitted, if any of the widgets enters (@a state equals @a true)
@@ -274,9 +274,9 @@ signals:
/**
* This signal is sent out, if any of the balance warning levels
* for @p account has been reached. @p msg contains the message text.
* @p tqparent points to the tqparent widget to be used for the warning message box.
*/
- void balanceWarning(TQWidget* tqparent, const MyMoneyAccount& account, const TQString& msg);
+ void balanceWarning(TQWidget* parent, const MyMoneyAccount& account, const TQString& msg);
protected:
TQValueList<MyMoneySplit> m_splits;
@@ -212,13 +212,13 @@ signals:
/**
* This signal is sent out, when a new category needs to be created
- * Depending on the setting of either a payment or deposit, the tqparent
+ * Depending on the setting of either a payment or deposit, the parent
* account will be preset to Expense or Income.
*
@@ -212,13 +212,13 @@ signals:
*
* @param account reference to account info. Will be filled by called slot
- * @param tqparent reference to tqparent account
+ * @param parent reference to parent account
*/
@@ -226,9 +226,9 @@ signals:
*
* @param account reference to account info. Will be filled by called slot
- * @param tqparent reference to tqparent account
+ * @param parent reference to parent account
*/
@@ -274,9 +274,9 @@ signals:
* This signal is sent out, if any of the balance warning levels
* for @p account has been reached. @p msg contains the message text.
- * @p tqparent points to the tqparent widget to be used for the warning message box.
+ * @p parent points to the parent widget to be used for the warning message box.
*/